
nestAbund.gui <- function() {

#'  Graphical user interface for nest abund program.
#'
#'  Graphical user interface for nest abund program.
#'@return returns nothing
#'@export
#'@details
#'  Gets input file, binary and continuous covariate variable names, and model specification.
#'  Then, allows the model to be run and AIC info saved to a table.
#'  To accomplish these tasks without the GUI (for use in scripts),  do the following:
#'      nestAbund.read.csv(filename)
#'      nestAbund.select.binCov(binCovName)
#'      nestAbund.select.contCov(contCovName)
#'      nestAbund.runmod(modname)
  gui<<-1

read.input <- function() {
   if (nchar(fName)<1) xxxstd=nestAbund.readcsv() else xxxstd=nestAbund.readcsv(fName)
   tkconfigure(inpfname.box,textvariable=tclVar(fileName))
   tkentryconfigure(topMenu,2,state="active")  # activate 'BinCovar' menu
   tkentryconfigure(topMenu,3,state="active")  # activate 'ContCovar' menu
   tkentryconfigure(topMenu,5,state="active")  # activate 'Run' menu
   sout<<-summarize_data()
   tkinsert(OP.box,"0.0",paste(sout,collapse="\n"))
   tkpack.forget(lab_hint_box)
   tkpack.forget(img_frame)
   s=dimnames(xdata)[[2]]
   for (i in 1:length(s)) {
     cbvalue[[i]]<<-tclVar(paste(0+(s[i]=='Cattle')))
     tkadd(bcovMenu,"checkbutton",label=s[i],variable=cbvalue[[i]],
         command=function() tclvalue(done)=71)
     ccvalue[[i]]<<-tclVar(paste(0+(s[i]=='Robel')))
     tkadd(ccovMenu,"checkbutton",label=s[i],variable=ccvalue[[i]],
         command=function() tclvalue(done)=72)
   }
   tkpack(OP.box,side="left"); tkpack(scr,side="right",fill="y");
   tkconfigure(statusbar.label,text="file read")
}

select.BinCov <- function(tmpName) {
  tmpCol=which(names(xdata)==tmpName)
  tmp.data=xdata[,tmpCol]
  if (sum(tmp.data!=0 & tmp.data!=1)>0) {
    cat('\n*** BinCov variable must contain only 0 or 1.\n')
  } else {
    BinCovName<<-tmpName; BinCovCol<<-tmpCol; cattle.data<<-tmp.data;
    prp=round(sum(tmp.data)/length(tmp.data),2)
    cat('\nProportion',tmpName,'>0=',prp,'\n')
  }
}

select.ContCov <- function(tmpName) {
  tmpCol=which(names(xdata)==tmpName)
  tmp.data=xdata[,tmpCol]
  ContCovName<<-tmpName; ContCovCol<<-tmpCol; robel.data<<-tmp.data
  shap.test=shapiro.test(ContCov.data)
  cat('\n --- Shapiro test of normality for',tmpName,':\n'); print(shap.test)
  cat('\nBinCovName:',BinCovName,' ContCovName:',ContCovName,'\n')
}



  if (sum(ls(1)=='zGH')<1) {cat('nestAbund.default()\n'); nestAbund.default()}

  # Create a new toplevel window
  tt <- tktoplevel(width=800,height=600);
  tkfont.configure("TkDefaultFont",  size = sz)
  tkfont.configure("TkTextFont",  size = sz)
  smfont=tkfont.create(size=sz-2,family="Lucida Console")
  sbarfont=tkfont.create(size=sz-2,slant="italic")
  normfont=tkfont.create(size=sz)
  boldfont=tkfont.create(weight="bold",size=sz)
  undfont=tkfont.create(family='Lucida Console',underline="yes",size=sz)
  boldf2=tkfont.create(weight="bold",size=sz*1.5)

  tkwm.title(tt,paste("nestAbund",VER,sep=''))  # Give the window a title

  about_text=paste('Program nestAbund','by G. Peron and J. Hines','ver ',VER,'(25  -Mar-2013)',
  'email jhines@usgs.gov','with questions or problems.',sep='\n')

  abstract='Beyond Survival:  Abundance  Estimation for Nest Studies\n
  A recurrent issue in studies of bird fecundity is that nests are
  difficult to find. Hatching success and fledging success can be
  inferred from detected nests, but the total number of offspring
  per unit of habitat remains unknown. Here we develop a capture-
  recapture approach to the issue that deals with imperfect
  detection probability as well as with the impact of environmental
  and individual covariates on nest fate. We tailor the approach
  to the estimation of duck productivity in the Prairie Pothole
  Region of North and South Dakota. In this study case, we use the
  age of the nests at first detection (estimated by the candling
  method) to make inference about detection probability. We
  describe the maximum likelihood estimation of the total number
  of nests on the study plots. We find that nesting stage (egg-
  laying or incubation) markedly influences both survival and
  detection probabilities, probably because hens often do not
  attend nests when they are not incubating. 6% of the nests
  were missed by the field crews during surveys, or failed
  before the nearest survey, or were initiated after the last
  survey. This proportion is expected to be larger in less
  intense, more typical sampling designs.'

  lb0="Abundance Estimation for Nest Studies"

  availmods=c('phi()p()',
  'phi(stage)p(stage)',
  'phi(stage+BinCov)p(stage+BinCov)',
  'phi(stage)p(stage+BinCov)',
  'phi(stage+BinCov)p(stage)',
  'phi(stage+ContCov)p(stage+ContCov)',
  'phi(stage)p(stage+ContCov)',
  'phi(stage+ContCov)p(stage)',
  'phi(stage+ContCov+BinCov)p(stage+ContCov+BinCov)',
  'phi(site)p(site)',
  'phi(site+stage)p(site+stage)',
  'phi(site+stage)p(site+stage+BinCov)',
  'phi(site+stage+BinCov)p(site+stage)',
  'phi(site+stage+BinCov)p(site+stage+BinCov)',
  'phi(site+stage+BinCov)p(stage+BinCov)',
  'phi(site+stage+BinCov)p(stage)',
  'phi(site+stage+ContCov)p(site+stage+ContCov)',
  'phi(site+stage)p(site+stage+ContCov)',
  'phi(site+stage+ContCov)p(site+stage)',
  'phi(site+stage+ContCov+BinCov)p(site+stage+ContCov+BinCov)')

  done <- tclVar(0)

  # Capture the event "Destroy" (e.g. Alt-F4 in Windows) and
  #         when this happens, assign 2 to done.
  tkbind(tt,"<Destroy>",function() tclvalue(done)<-2)

  topMenu <- tkmenu(tt); tkconfigure(tt,menu=topMenu)

  fileMenu <- tkmenu(topMenu,tearoff=FALSE)
   tkadd(fileMenu,"command",label="Open previous results",command=function() tclvalue(done)<-4)
   tkadd(fileMenu,"command",label="Exit",command=function() tclvalue(done)<-21)
   if (length(grep('jhines',Sys.getenv('HOME')))>0) {
     tkadd(fileMenu,"command",label="===Quit",command=function() tclvalue(done)<-99)
     tkadd(fileMenu,"command",label="===make zipfile",command=function() make_zip())
     tkadd(fileMenu,"command",label="===make nxtver",command=function() make_nxtver())
     tkadd(fileMenu,"command",label="===make GH file",command=function() make_GH())
   }
   tkadd(topMenu,"cascade",label="File",menu=fileMenu)

    cbvalue=list()
    bcovMenu<-tkmenu(topMenu,tearoff=FALSE)
    ccvalue=list()
    ccovMenu<-tkmenu(topMenu,tearoff=FALSE)
     tkadd(topMenu,"cascade",label="BinaryCov",menu=bcovMenu,state='disabled')
     tkadd(topMenu,"cascade",label="ContCov",menu=ccovMenu,state='disabled')
    modMenu<-tkmenu(topMenu,tearoff=FALSE)

    distMenu<-tkmenu(topMenu,tearoff=FALSE)
    sSCR=c('site','Stage','Cattle','Robel')
    dbtn1=tclVar('GAU');
    tkadd(distMenu,"radiobutton",label="GAU",variable=dbtn1)
    tkadd(distMenu,"radiobutton",label="RCOS",variable=dbtn1)
    tkadd(distMenu,"radiobutton",label="TIME",variable=dbtn1)

    otherMenu<-tkmenu(modMenu,tearoff=F)
    phiMenu<-tkmenu(modMenu,tearoff=FALSE)
    pMenu<-tkmenu(modMenu,tearoff=FALSE)
    phibtn=list();
    for (i in 1:length(availmods)) {
      phibtn[[i]]=tclVar('0')
      tkadd(otherMenu,"checkbutton",label=availmods[i],variable=phibtn[[i]])
    }
    fibtn=list(); pbtn=list(); fimods=c(".","site","stage","BinCov","ContCov")
    for (i in 1:length(fimods)) {
      fibtn[[i]]=tclVar(paste(0)); pbtn[[i]]=tclVar(paste(0))
      tkadd(phiMenu,"checkbutton",label=fimods[i],variable=fibtn[[i]])
      tkadd(pMenu,"checkbutton",label=fimods[i],variable=pbtn[[i]])
    }
    tkadd(topMenu,"cascade",label="Models",menu=modMenu)
    tkadd(modMenu,"cascade",label='Model-Phi',menu=phiMenu)
    tkadd(modMenu,"cascade",label='Model-P',menu=pMenu)
    tkadd(modMenu,"cascade",label='Pre-Defined models',menu=otherMenu)
    tkadd(modMenu,"cascade",label='distribution',menu=distMenu)

  runMenu <- tkmenu(topMenu,tearoff=FALSE)
   tkadd(runMenu,"command",label="Models",command=function() tclvalue(done)<-3)
   tkadd(topMenu,"cascade",label="Run",menu=runMenu,state="disabled")

  cfgMenu <- tkmenu(topMenu,tearoff=FALSE)
   tkadd(cfgMenu,"command",label="maxbs:500",command=function() tclvalue(done)<-62)
   tkadd(cfgMenu,"command",label="maxit:500",command=function() tclvalue(done)<-61)
   tkadd(cfgMenu,"command",label="GHnodes:15",command=function() tclvalue(done)<-6)
   tkadd(cfgMenu,"command",label="INCUBLEN:34",command=function() tclvalue(done)<-63)
   tkadd(cfgMenu,"command",label="AvgClutch:10",command=function() tclvalue(done)<-64)
   tkadd(cfgMenu,"command",label="DaySamp:",command=function() tclvalue(done)<-65)
   #tkadd(cfgMenu,"command",label="DEBUG",command=function() DEBUG<<-1)
   tkadd(topMenu,"cascade",label="Config",menu=cfgMenu)

   cfgdefs=c(
   'maxbs      - number of bootstrap simulations for estimation of conf. intervals',
   'maxit        - maximum number of iterations for the optimization routine',
   'GHnodes   - number of nodes in Gauss-Hermite quadrature',
   'INCUBLEN  - incubation length or  nest lifespan (eg.,10 days egg laying + 24 days incub)',
   'AvgClutch - Avg. time for clutch completion (=clutch size for species that lay 1 egg per day)')
   cfgdefs=paste(cfgdefs,collapse='\n')

  helpMenu <- tkmenu(topMenu,tearoff=FALSE)
   tkadd(helpMenu,"command",label="About",command=function() tclvalue(done)<-5)
   tkadd(helpMenu,"command",label="Abstract",command=
           function() tkmessageBox(title=lb0,message=abstract))
   tkadd(helpMenu,"command",label="General",command=
           function() help(package=nestAbund2) )
   tkadd(helpMenu,"command",label="Why Run menu is unavailable",command=
           function() tkmessageBox(title='answer',message=
           'An input file must be specified before models can be run.'))
   tkadd(helpMenu,"command",label="config parameters",command=
           function() tkmessageBox(title='config definitions',message=cfgdefs))
   tkadd(topMenu,"cascade",label="Help",menu=helpMenu)

  xlb0=tklabel(tt,text=lb0,font=boldf2)
  tkpack(xlb0)

  inpfname=tclVar("no file selected yet");

  input_filename_frame=tkframe(tt)
   inpfname.box<<-tkentry(input_filename_frame,width=80,textvariable=inpfname)
   lbl1=tkbutton(input_filename_frame,text="Input file:",command=function() read.input())
   tkpack(lbl1,side="left",padx=5); tkpack(inpfname.box,side="right",padx=5)
  tkpack(input_filename_frame)

  lab_hint_box=tklabel(tt,bg="white",fg="blue",justify="left",text=
  "Start by selecting an input file with the
  'Input file' button. Then, select binary and continous
  covariates (optional), then select models and click
  'Run/models' menu.")
  tkpack(lab_hint_box)

  img_frame=tkframe(tt)
  image1 <- tclVar()
  duckpic=system.file('figs/duck_on_nest.gif',package='nestAbund')
  cat('duckpic:',duckpic,'\n')
  if (runif(1)<.59) duckpic=system.file('figs/duck_nest.gif',package='nestAbund')
  tcl("image","create","photo",image1,file=duckpic)
  imgAsLabel <- tklabel(img_frame,image=image1)
  tkpack(imgAsLabel)
  tkpack(img_frame)

  inp_results_frame=tkframe(tt)
   OP.box<<-tktext(inp_results_frame,width=80,height=23,font=smfont,wrap="none")
   OPval=tkinsert(OP.box,"end","\n")
   scr <- tkscrollbar(inp_results_frame, repeatinterval=5,width=20,
                         command=function(...)tkyview(OP.box,...))
  tkpack(inp_results_frame,anchor="w")

  mod_results_frame<<-tkframe(tt)
  results_hdr_line=tkbutton(mod_results_frame,borderwidth=0,text=
#    'npar   dltaAIC    AIC      Neg.LL  mod.wgt   mod.like  Model                   ',
    'npar  AIC  Neg.LL dist    BinCov    ContCov    Model                   ',
      height=1,font=undfont)
  tkconfigure(results_hdr_line,command=function() {
                sortcol<<-sortcol+1;if (sortcol>4)sortcol<<-0; sort_aic();
                })
  tkpack(mod_results_frame,anchor="w")

  sbar.label<<-tkframe(tt)
  statusbar.label<<-tklabel(sbar.label,width=66,text="",font=sbarfont,fg='dark green')
  sbar2<<-tklabel(sbar.label,text="",font=sbarfont,fg='dark green')
  tkpack(statusbar.label,side="left")
  tkpack(sbar2,side="right")
  tkpack(sbar.label,anchor="w",side="bottom")

  tkfocus(tt);

  pgmdone=0
  while (pgmdone==0) {
    tkwait.variable(done)

    distr=tclvalue(dbtn1);

    if (tclvalue(done)==5) {      #  display help/about message
      tkmessageBox(title='nestAbund',message=about_text)
    }

    if (tclvalue(done)==6) {
      Q<<-as.numeric(inputBox('nestAbund','New value for GHnodes','15'))
      tkentryconfigure(cfgMenu,2,"-label",paste("GHnodes=",Q,sep=''))
      if (Q!=15) {
        if (Q<=20) {
          zGH=zGHmat[Q,1:Q]; wGH=wGHmat[Q,1:Q]
        } else {
          i=require('fastGHQuad')
          if (!i) {
            j=tkmessageBox(message="package fastGHQuad required, do you want to install now?",
            icon = "question", type = "yesno", default = "yes")
            if (tclvalue(j)=="yes") install.packages('fastGHQuad')
          }
        }
      }
      library(fastGHQuad)
      zGH=gaussHermiteData(Q)$x; wGH=gaussHermiteData(Q)$w
    }
    if (tclvalue(done)==61) {
      maxit=as.numeric(inputBox('nestAbund','New value for maxit','500'))
      tkentryconfigure(cfgMenu,1,"-label",paste("maxit=",maxit,sep=''))
    }
    if (tclvalue(done)==62) {
      maxbs=UUU=as.numeric(inputBox('nestAbund','New value for maxbs','500'))
      tkentryconfigure(cfgMenu,0,"-label",paste("maxbs=",maxbs,sep=''))
    }
    if (tclvalue(done)==63) {
      INCUBLEN=as.numeric(inputBox('nestAbund','New value','34'))
      tkentryconfigure(cfgMenu,3,"-label",paste("INCUBLEN=",INCUBLEN,sep=''))
    }
    if (tclvalue(done)==64) {
      AvgClutch=as.numeric(inputBox('nestAbund','Avg. time for\nclutch completion','10'))
      tkentryconfigure(cfgMenu,4,"-label",paste("AvgClutch=",AvgClutch,sep=''))
    }
    if (tclvalue(done)==65) {
      dsfileName<<-tclvalue(tkgetOpenFile())
      if (!nchar(dsfileName)) {
        tkmessageBox(title="nestAbund",message = "No DaySampl csv file was selected!")
      } else  {
          DaySampl.tmp=as.matrix(read.csv(dsfileName,header=F)); ier=0
          for (i in 1:dim(DaySampl)[1]) {
            jj=which(DaySampl[i,]>0,arr.ind=T)
            if (sum(!(DaySampl[i,jj] %in% DaySampl.tmp[i,]))>0) ier=1
          }
          if (ier) {
            s='Error:each day in data must occur in DaySampl'
            cat('\n',s,'\n\nDaySampl from data:\n'); print(DaySampl)
            cat('\ninput DaySampl:\n'); print(DaySampl.tmp); cat('\n')
            tkmessageBox(title='nestAbund',message=s)
          } else {
            DaySampl<<-DaySampl.tmp
            cat('\nDays of visits to the study site(s) [site/visit number]\n'); print(DaySampl); cat('===================\n')
            tkentryconfigure(cfgMenu,5,"-label",paste("DaySamp=",dsfileName,sep=''))
          }
      }
    }
    if (tclvalue(done)==71) {
      for (i in 1:dim(xdata)[2]) {
        j=tclvalue(tclvalue(.Tcl(paste(bcovMenu,"entrycget",i-1,"-variable"))))
        if (j=="1") {
          tmpName=tclvalue(.Tcl(paste(bcovMenu,"entrycget",i-1,"-label")))
          tmpCol=which(names(xdata)==tmpName)
          tmp.data=xdata[,tmpCol]
          if (sum(tmp.data!=0 & tmp.data!=1)>0) {
            tkmessageBox(title='nestAbund',message='BinCov variable must contain only 0 or 1.')
          } else {
            BinCovName<<-tmpName; BinCovCol<<-tmpCol; cattle.data<<-tmp.data;
            prp=round(sum(tmp.data)/length(tmp.data),2)
            cat('\nProportion',tmpName,'>0=',prp,'\n')
            sout2=c(' ',paste('Proportion',tmpName,'>0 =',prp))
            sbar.bname=paste('BinCovName:',BinCovName,' ContCovName:',ContCovName,sep='')
            tkconfigure(sbar2,text=sbar.bname)
            OPval=tkinsert(OP.box,"end",paste(sout2,collapse='\n'))
          }
        }
      }
    }
    if (tclvalue(done)==72) {
      for (i in 1:dim(xdata)[2]) {
        j=tclvalue(tclvalue(.Tcl(paste(ccovMenu,"entrycget",i-1,"-variable"))))
        if (j=="1") {
          tmpName=tclvalue(.Tcl(paste(ccovMenu,"entrycget",i-1,"-label")))
          tmpCol=which(names(xdata)==tmpName)
          tmp.data=xdata[,tmpCol]
          ContCovName<<-tmpName; ContCovCol<<-tmpCol; ContCov.data<<-tmp.data
          shap.test=shapiro.test(ContCov.data)
          cat('\n --- Shapiro test of normality for',tmpName,':\n'); print(shap.test)
          sout2=c(' ',paste('Shapiro test of normality for',tmpName,':W=',
            round(shap.test$statistic,2),'p-value=',round(shap.test$p.value,2)))
          sbar.bname=paste('BinCovName:',BinCovName,' ContCovName:',ContCovName,sep='')
          tkconfigure(sbar2,text=sbar.bname)
          OPval=tkinsert(OP.box,"end",paste(sout2,collapse='\n'))
        }
      }
    }

    if (tclvalue(done)==4) {     #  read output files in current directory
      if (length(xdata)<1) {
        tkmessageBox(title='nestAbund',message="Input file must be specified first!")
      } else {
        cdir=tclvalue(tkchooseDirectory())   #  and get log-likelihood values to put
        setwd(cdir)                          #  in button lables
        cat('cur dir:',getwd(),'\n'); f='nestAbund_input_summary.txt'
        if (file.exists(f)) sout=readLines(f);
        outname=list.files('.',paste('nestAbund_phi.+',distr,'.out',sep=''),ignore.case=T); j1=j2=0
        if (length(outname)>0) {
          ii=0
          for (i in 1:length(outname)) {
            cat('reading',outname[i],'\n');
            a=readLines(outname[i]); j=grep('Loglike',a,ignore.case=T);
            if (length(j)<1) { cat('\n***************\n',a,'\n************\n') } else {
              ll=as.numeric(unlist(strsplit(a[j],'='))[2])
              j=grep('odel:',a)
              mname=as.character(unlist(strsplit(a[j],': '))[2]); j1=j2=0
              i1=grep('ntransformed estimates',a); i2=grep('Transformed estimates',a);
              if (length(i2)>0 & length(i1)>0) {
                b=a[i1:i2]; b2=b[grep("Survival:",b)]; b3=b2[grep("site",b2,invert=T)]
                b4=strsplit(b3[grep("Stage",b3,invert=T)]," ")
                BinCovName=b4[[1]][2]; ContCovName=b4[[2]][2]
                fName<<-substr(a[grep("input data file",a)],18,99)
                if (BinCovCol==0) {
                  j1=which(names(xdata)==BinCovName);
                  if (length(j1)>0) {
                    BinCovCol<<-j1
                    tkentryconfigure(bcovMenu,BinCovCol-1,variable=tclVar("1"))  # activate 'BinCovar' menu
                  }
                  j2=which(names(xdata)==ContCovName);
                  if (length(j2)>0) {
                    ContCovCol<<-j2
                    tkentryconfigure(ccovMenu,ContCovCol-1,variable=tclVar("1"))  # activate 'BinCovar' menu
                  }
                  sbar.bname=paste('BinCovName:',BinCovName,' ContCovName:',ContCovName,sep='')
                  tkconfigure(sbar2,text=sbar.bname)
                }
                np=as.numeric(substr(a[grep('number of parameters',a)],22,99));
                aic=2*ll+2*np ;
                x=sprintf('%4d   0.0  %9.3f   %9.3f 0.0 0.0  %s',np,aic,ll,mname);
                ii=ii+1 ; ii=length(modbtn)+1
                if (ii==1) {
                  tkpack.forget(lab_hint_box)     #  hide hint box
                  tkpack.forget(img_frame)         #  hide image frame box
                  tkpack.forget(inp_results_frame)  #  hide input_results box
                  tkpack(results_hdr_line,anchor="w")
                }
                modbtn[[ii]]<<-tkbutton(mod_results_frame,font=tblfont,
                  text=x,borderwidth=0,command=eval(substitute(function()
                    system(paste('notepad',outname[j]),wait=F),list(j=i))))
                tkpack(modbtn[[ii]],anchor="w")
              }
            }
          }
          if (ii>0) {
            tkconfigure(inpfname.box,textvariable=tclVar(fileName))
            tkentryconfigure(topMenu,2,state="active")  # activate 'BinCovar' menu
            tkentryconfigure(topMenu,3,state="active")  # activate 'ContCovar' menu
            tkentryconfigure(topMenu,5,state="active")  # activate 'Run' menu
            tkconfigure(statusbar.label,text=
            "Click model name to view model output.")
          }
        } else {
          tkconfigure(statusbar.label,text="No model output files in folder.")
          tkmessageBox(title="nestAbund",message="No model output files in folder.")
        }
        sortcol=1; sort_aic()
      }
    }

    if (tclvalue(done)==2) { pgmdone=1; tkdestroy(tt) } #  exit program
    if (tclvalue(done)==21) { #  exit program
      pgmdone=1;
      if (length(tmp)>0) {
        save(maxit,maxbs,Q,INCUBLEN,UUU,file=ftmp)
        sout=c(sout,' ','npar  AIC  Neg.Log-like   Model',' ')
        if (length(modbtn)>0) {
          for (i in 1:length(modbtn)) {
            sout=c(sout,tclvalue(.Tcl(paste(modbtn[[i]],"cget -text"))))
          }
          writeClipboard(paste(sout,collapse='\n'))
        }
      }
      tkdestroy(tt);
    }

    if (tclvalue(done)==99) { #  exit program, but leave tcl window open
      pgmdone=1;
      if (length(tmp)>0) save(list=ls(),file='nestAbund.tmp.rdata')
    }

    if (tclvalue(done)==3) {     #    run models
      tkpack(results_hdr_line,anchor="w")
      cattle.data<<-robel.data<<-rep(0,dim(xdata)[1])
      for (i in 1:dim(xdata)[2]) {
        j=tclvalue(tclvalue(.Tcl(paste(bcovMenu,"entrycget",i-1,"-variable"))))
        if (j=="1") {
          BinCovName<<-tclvalue(.Tcl(paste(bcovMenu,"entrycget",i-1,"-label")))
          BinCovCol<<-which(names(xdata)==BinCovName)
          cattle.data<<-xdata[,BinCovCol]
        }
      }
      for (i in 1:dim(xdata)[2]) {
        j=tclvalue(tclvalue(.Tcl(paste(ccovMenu,"entrycget",i-1,"-variable"))))
        if (j=="1") {
          ContCovName<<-tclvalue(.Tcl(paste(ccovMenu,"entrycget",i-1,"-label")))
          ContCovCol<<-which(names(xdata)==ContCovName)
          robel.data<<-xdata[,ContCovCol]
        }
      }
      for (i in 1:length(availmods))    #  Run models selected from menus
        if (tclvalue(phibtn[[i]])>0)
          a=nestAbund.runmod(paste(availmods[i],distr,sep=''))
      s1=s2=NULL
      for (i in 1:length(fimods)) {   #  Run models selected from menus
        if (tclvalue(fibtn[[i]])>0) s1=paste(s1,fimods[i],sep='+')
        if (tclvalue(pbtn[[i]])>0) s2=paste(s2,fimods[i],sep='+')
      }
      s1=gsub("^\\+","",s1); s2=gsub("^\\+","",s2)
      ss=paste("phi(",s1,")p(",s2,")",sep="") ;
      if ((length(s1)+length(s2))>0) a=nestAbund.runmod(paste(ss,distr,sep=''))
    }
  } #  end while pgmdone==0
} #  end nestAbund_gui
cat('finished\n')
