
nestAbund.runmod <- function(mname='Phi()P()GAU',init=NULL) {
#' Analyze nest abund. data, for a given model
#'
#'     This function is called from the GUI, but may be run as a command from an R script.
#'
#'@param mname input model name
#'@param init initial values of parameters
#'@return   returns list of optimization results:
#'       \item{ss1$code}{optimization completion code}
#'       \item{ss1$estimate}{maximum likelihood estimates}
#'       \item{ss1$mimimum}{negative maximum likelihood value}
#'@export
#' @details
#' model-name : Phi or P can vary by zero or more of the following:
#'
#' \emph{site, stage, BinCov, ContCov}.  To specify a model, simply
#' set the model name to Phi(xxx)P(yyy), where
#' xxx and yyy are combinations of the 4 possibilities
#' joined by '+'.
#'
#' For example, Phi(site)P() would
#' specify a model where survival varies by site, but is
#' constant with respect to nest stage and covariates.  Detection
#' (P) is constant with respect to site, stage and covariates.
#'
#' To run a model using the GUI, go to the 'Models/Model-Phi' or
#' 'Models/Model-P' menus and select
#' one or more of the sub-menu items.  Or, choose one of the pre-defined
#' models.
#'
#' There are 3 choices for the distribution of entry-dates in the
#' model (GAU=default, RCOS, and TIME).  In the GUI, one of the other
#' distributions can be selected via the distribution menu under 'Model/Model-Phi'
#' or 'Model/Model-P'.  If not using the GUI, append one of the other choices
#' onto the end of the modname parameter (eg., Phi(site+stage)P()RCOS).
#'
#' This function cannot be run until the data have been input and binary and continuous covariates have been selected
  distributions=c('GAU','RCOS','TIME'); rbl=c('robel','restricted','robel')
  mname2=gsub("BinCov",BinCovName,gsub("ContCov",ContCovName,mname))
  i=length(grep('RCOS',mname2))+length(grep('TIME',mname2))*2
  k=length(grep('restricted',mname2)); dst=distributions[1+i]
  outname=paste(getwd(),'/nestAbund_',gsub('+','P',mname2,fixed=T),'.out',sep='')
  procname=paste("ss1<-",dst,"_",rbl[k+1],"('",mname2,"',init)",sep='')
  gui=(sum(ls(1)=='statusbar.label')>0)
  if (gui) tkconfigure(statusbar.label,text=paste('running',mname2,'...'));
  #cat(procname,'\n')
  sink(outname,split=T)
  cat('\nnestAbund version',VER,' date:',date(),'\n')
  cat('\ninput data file:',fileName,'\n');
  cat('\nmodel:',mname2,'\n\n');
  eval(parse(text=procname))   #  call R procedure using procname
  #load("nest_abundphi(site+stage+cattle)p(stage+cattle)TIME.rdata"); ss=ss1
  sink();
  if (!is.null(ss1)) {
    theta1=ss1$estimate; ll=ss1$minimum; np=length(theta1)
    aic=2*ll-2*np; cat('>>>>',ll,np,aic,'\n')
    v=sprintf('%4d   %7.2f %7.2f %12s %12s %12s %s',
                np,aic,ll,dst,BinCovName,ContCovName,mname2)
    if (gui) {
      tkconfigure(statusbar.label,text=paste('finished running',mname2,'...'))
      j=length(modbtn)+1
      modbtn[[j]]<<-tkbutton(mod_results_frame,font=tblfont,text=v,
              borderwidth=0,command=eval(substitute(function()
               shell(paste('notepad',outname),wait=F),list(j=i))))
      tkpack(modbtn[[j]],anchor="w")
      sort_aic();
      tkconfigure(statusbar.label,
      text="Click model name to view model output.    Table of model results will be copied to clipboard on exit.")
    }
  }
  return(ss1)
}
